@@ -17,26 +17,42 @@
   'use strict';
 
   describe('LBaaS v2 Member Detail Controller', function() {
-    var lbaasv2API, ctrl, actions;
+    var $controller, lbaasv2API, membersService, apiFail, qAllFail, actions;
 
-    function fakeAPI() {
+    function fakePromise(data, reject) {
       return {
-        success: function(callback) {
-          callback('foo');
+        then: function(success, fail) {
+          if (reject) {
+            fail();
+          } else {
+            success({ data: data });
+          }
+          return fakePromise();
         }
       };
     }
 
+    function fakeAPI() {
+      return fakePromise('foo', apiFail);
+    }
+
     function loadbalancerAPI() {
-      var loadbalancer = { provisioning_status: 'ACTIVE' };
-      return {
-        success: function(callback) {
-          callback(loadbalancer);
-        },
-        then: function(callback) {
-          callback({ data: loadbalancer });
+      return fakePromise({ provisioning_status: 'ACTIVE' });
+    }
+
+    function qAll() {
+      return fakePromise(null, qAllFail);
+    }
+
+    function createController() {
+      return $controller('MemberDetailController', {
+        $routeParams: {
+          loadbalancerId: 'loadbalancerId',
+          listenerId: 'listenerId',
+          poolId: 'poolId',
+          memberId: 'memberId'
         }
-      };
+      });
     }
 
     ///////////////////////
@@ -48,6 +64,10 @@
     beforeEach(module('horizon.dashboard.project.lbaasv2'));
 
     beforeEach(module(function($provide) {
+      apiFail = false;
+      qAllFail = false;
+
+      $provide.value('$q', { all: qAll });
       $provide.value('$uibModal', {});
       $provide.value('horizon.dashboard.project.lbaasv2.members.actions.rowActions', {
         init: function() {
@@ -60,39 +80,53 @@
 
     beforeEach(inject(function($injector) {
       lbaasv2API = $injector.get('horizon.app.core.openstack-service-api.lbaasv2');
+      actions = $injector.get('horizon.dashboard.project.lbaasv2.members.actions.rowActions');
+      membersService = $injector.get('horizon.dashboard.project.lbaasv2.members.service');
       spyOn(lbaasv2API, 'getMember').and.callFake(fakeAPI);
       spyOn(lbaasv2API, 'getPool').and.callFake(fakeAPI);
       spyOn(lbaasv2API, 'getListener').and.callFake(fakeAPI);
       spyOn(lbaasv2API, 'getLoadBalancer').and.callFake(loadbalancerAPI);
-      actions = $injector.get('horizon.dashboard.project.lbaasv2.members.actions.rowActions');
       spyOn(actions, 'init').and.callThrough();
-      var controller = $injector.get('$controller');
-      ctrl = controller('MemberDetailController', {
-        $routeParams: {
-          loadbalancerId: 'loadbalancerId',
-          listenerId: 'listenerId',
-          poolId: 'poolId',
-          memberId: 'memberId'
-        }
-      });
+      spyOn(membersService, 'associateMemberStatuses');
+      $controller = $injector.get('$controller');
     }));
 
     it('should invoke lbaasv2 apis', function() {
+      var ctrl = createController();
       expect(lbaasv2API.getMember).toHaveBeenCalledWith('poolId','memberId');
       expect(lbaasv2API.getPool).toHaveBeenCalledWith('poolId');
       expect(lbaasv2API.getListener).toHaveBeenCalledWith('listenerId');
       expect(lbaasv2API.getLoadBalancer).toHaveBeenCalledWith('loadbalancerId');
-      expect(ctrl.loadbalancer).toEqual({ provisioning_status: 'ACTIVE' });
-      expect(ctrl.listener).toBe('foo');
-      expect(ctrl.pool).toBe('foo');
-      expect(ctrl.member).toBe('foo');
-    });
-
-    it('should have actions', function() {
+      expect(ctrl.loadbalancerId).toBeDefined();
+      expect(ctrl.listenerId).toBeDefined();
+      expect(ctrl.poolId).toBeDefined();
+      expect(ctrl.operatingStatus).toBeDefined();
+      expect(ctrl.provisioningStatus).toBeDefined();
       expect(ctrl.actions).toBe('member-actions');
       expect(actions.init).toHaveBeenCalledWith('loadbalancerId', 'poolId');
     });
 
+    it('should invoke the "associateMemberStatuses" method', function() {
+      var ctrl = createController();
+      expect(membersService.associateMemberStatuses).toHaveBeenCalledWith(
+          ctrl.loadbalancerId, ctrl.listenerId, ctrl.poolId, [ctrl.member]);
+    });
+
+    it('should throw error on API fail', function() {
+      apiFail = true;
+      var init = function() {
+        createController();
+      };
+      expect(init).toThrow();
+    });
+
+    it('should set error state if any APIs fail', function() {
+      qAllFail = true;
+      var ctrl = createController();
+      expect(ctrl.loading).toBe(false);
+      expect(ctrl.error).toBe(true);
+    });
+
   });
 
 })();
